@@ -1,16 +1,18 @@
 
 class filter_data:
-        ''' In multiple filter function you can filter upto ten data 10 
-        only you have to pass yor value as list(respect to multiple filter)
-        '''
-    def pysprk_filter(df,column,val):
+    def __int__(self):
+        self.self=self
+    ''' In multiple filter function you can filter upto ten data 10 
+    only you have to pass yor value as list(respect to multiple filter)'''
+    def pysprk_filter(self,df,val):
         '''
         df="Data Frame"
         Column="target column"
         val -> "string/List"
         '''
+        column=input('Enter your target ciolumn name :')
         typ=input("kindly enter \n which filter do you want to perorm\n 0 -> 'Equal'\n 1 -> 'not-Equal' \n 2 -> 'isnull' \n kindly pass your value as 1 or 2 or 3 \n")
-        if typ=="Equal":
+        if typ=="0":
             if type(val)==list and len(val)<=10:
                 if len(val)==2:
                     df=df.filter((col(column)==val[0])|(col(column)==val[1]))
@@ -42,7 +44,7 @@ class filter_data:
                 df=df.filter(col(column)==val)
             else:
                 pass
-        elif typ=="not-Equal":
+        elif typ=="1":
             if type(val)==list and len(val)<=10:
                 if len(val)==2:
                     df=df.filter((col(column)!=val[0])|(col(column)!=val[1]))
@@ -74,7 +76,7 @@ class filter_data:
                 df=df.filter(col(column)!=val)
             else:
                 pass
-        elif typ=="isnull()":
+        elif typ=="2":
             df=df.filter(col(column).isNull())
         else:
             pass
